import { Connect, Datasource } from '@genesislcap/foundation-comms';
import { FASTElement } from '@microsoft/fast-element';
import type { ServicesStatusConfig, ServiceItem } from './main.types';
/**
 * The `ServicesStatus` component is designed to monitor and display the status of various services in real-time.
 * It leverages a connection to a backend datasource to receive updates about services status
 * and displays these updates to the user.
 *
 * @public
 */
export declare class ServicesStatus extends FASTElement {
    connect: Connect;
    datasource: Datasource;
    allMessages: ServiceItem[];
    allMessagesChanged(): void;
    displayMessages: ServiceItem[];
    resourceName: string;
    closeTimeout: ServicesStatusConfig['closeTimeout'];
    autoClose: ServicesStatusConfig['autoClose'];
    maxMessages: ServicesStatusConfig['maxMessages'];
    maxMessagesChanged(): void;
    eventNameCloseMessage: "dismiss";
    eventNameAutoCloseMessage: "autoDismiss";
    private datasourceSubscription;
    connectedCallback(): void;
    disconnectedCallback(): void;
    addMessage(newMessage: ServiceItem | ServiceItem[]): void;
    private updateDisplayMessages;
    private prepareServiceItem;
    private startMonitoring;
    private handleDataStream;
    stopMonitoring(): void;
    private closeMessageHandler;
    emitCloseMessage(target: any, identifier: any): void;
}
/**
 * ZeroServicesStatus.
 *
 * @remarks
 * A zero version that pre-registers zero components and uses the zero design system.
 *
 * @example
 * ```ts
 * import { ZeroServicesStatus } from '@genesislcap/foundation-services-status';
 * ...
 * ZeroServicesStatus
 * ```
 *
 * @example Load the micro frontend on-demand
 * ```ts

 *   const { ZeroServicesStatus } = await import('@genesislcap/foundation-services-status');
 *   return ZeroServicesStatus;
 * },
 * ```
 *
 * @public
 */
export declare class ZeroServicesStatus extends ServicesStatus {
    /**
     * @internal
     */
    connectedCallback(): Promise<void>;
    /**
     * @internal
     */
    protected loadRemotes(): Promise<void>;
}
//# sourceMappingURL=main.d.ts.map