import { closeIcon } from '@genesislcap/foundation-ui';
import { html, repeat } from '@microsoft/fast-element';
const getServiceStatusMessageTemplate = (prefix, item, type) => html `
  <${prefix}-snackbar
    identifier=${item.id}
    class="service-status-message service-status-message-${type}"
    auto-close="${(x, c) => c.parent.autoClose}"
    close-timeout="${(x, c) => c.parent.closeTimeout}"
    @autoDismiss=${(x, c) => c.parent.closeMessageHandler(c.event)}
  >
    <p class="content" slot="content">
      <span class="content-element content-service-name">${item.name} Service ${type === 'restored' ? 'back online' : 'outage'}</span>
      <span class="content-element content-text">
        ${type === 'restored'
    ? `Thank you for your patience while we were restoring service. The ${item.name} service is now available as normal. Please refresh your page to update`
    : `We're sorry, ${item.name} service is experiencing technical difficulties. It is recommended that you save your data before disconnecting from the application. Data is not current and may be incomplete`}
      </span>
      <span class="content-element content-buttons">
        <${prefix}-button class="link" @click=${() => confirm('Reload the page?') && location.reload()}>
          Reload
        </${prefix}-button>
      </span>
    </p>
    ${type === 'restored'
    ? html `<section class="action" slot="action">
          <${prefix}-button class="button-close" @click=${(x, c) => c.parent.emitCloseMessage(c.event.target, item.id)}>
            ${closeIcon('start', 'var(--close-icon-fill)')}
          </${prefix}-button>
        </section>`
    : ''}
  </${prefix}-snackbar>
`;
/**
 * @public
 */
export const getPrefixedServicesStatus = (designSystemPrefix, templates = {
    restored: (prefix, item) => getServiceStatusMessageTemplate(prefix, item, 'restored'),
    failed: (prefix, item) => getServiceStatusMessageTemplate(prefix, item, 'failed'),
}) => html `
  <div class="services-status" data-test-id="services-status">
    <slot>
      ${repeat((x) => x.displayMessages, html `
          ${(item) => item.isWorking
    ? templates.restored(designSystemPrefix, item)
    : templates.failed(designSystemPrefix, item)}
        `)}
    </slot>
  </div>
`;
